.. _naming-variables:

##################
 Naming variables
##################

***************
 rename filter
***************

The rename filter is used to rename variables in a dataset.

.. _remapping_option:

******************
 remapping option
******************

TODO.
